@@ -1,4 +1,5 @@
 from starlette.requests import Request
+from starlette.websockets import WebSocket
 import inspect
 
 
@@ -8,8 +9,9 @@ class Middleware:
 
     async def __call__(self, scope, receive, send):
         request = Request(scope=scope, receive=receive)
+        websocket = WebSocket(scope=scope, receive=receive, send=send)
 
-        response = await self.app.handle_request(request)
+        response = await self.app.handle_request(request, websocket)
 
         await response(scope, receive, send)
 
@@ -31,7 +33,7 @@ class Middleware:
             self.process_response(request)
 
         response = await self.app.handle_request(request)
-        
+
         if inspect.iscoroutinefunction(self.process_response):
             await self.process_response(request, response)
         else:
